package handler

import (
	"github.com/gin-gonic/gin"
	"health-go/model"
	"health-go/service/hospital"
	"health-go/util"
)

func FetchHospitalList(c *gin.Context) {
	if res, err := hospital.FetchAll(); err != nil {
		util.ReturnJson(c, 500, "获取医院列表失败", err)
		return
	} else {
		util.ReturnJson(c, 200, "获取医院列表成功", res)
	}
}

func AddHospital(c *gin.Context) {
	var newHospital model.Hospital
	if err := c.ShouldBindJSON(&newHospital); err != nil {
		util.ReturnInvalid(c)
		return
	}
	if ok, err := hospital.Add(newHospital); ok {
		util.ReturnJson(c, 200, "添加医院成功", nil)
	} else {
		util.ReturnJson(c, 500, "添加医院失败", err)
		return
	}
}

func ModifyHospital(c *gin.Context) {
	var hos model.Hospital
	if err := c.ShouldBindJSON(&hos); err != nil {
		util.ReturnInvalid(c)
		return
	}
	if ok, err := hospital.Modify(hos); ok {
		util.ReturnJson(c, 200, "修改医院信息成功", nil)
	} else {
		util.ReturnJson(c, 500, "修改医院信息失败", err)
		return
	}
}

// DeleteHospital
// @Accept       json
// @Produce      json
// @Param hos_id query int true "医院id" "maxlength(100)"
func DeleteHospital(c *gin.Context) {
	var hos model.Hospital
	if err := c.ShouldBindJSON(&hos); err != nil {
		util.ReturnInvalid(c)
		return
	}
	if ok, err := hospital.Delete(hos.HospitalID); ok {
		util.ReturnJson(c, 200, "删除指定医院成功", nil)
	} else {
		util.ReturnJson(c, 500, "删除指定医院失败", err)
		return
	}
}
