package router

import (
	"github.com/gin-gonic/gin"
	swaggerFiles "github.com/swaggo/files"
	ginSwagger "github.com/swaggo/gin-swagger"
	"health-go/handler"
	"health-go/service/sms"
)

func SetupRouter() *gin.Engine {
	gin.SetMode(gin.ReleaseMode)
	r := gin.Default()

	// user
	r.GET("/", handler.TestPage)
	r.GET("/firstUser", handler.FirstUser)

	// record
	r.GET("/api/fetchAllRec", handler.FetchAllRecords)
	r.POST("/api/insertRec", handler.InsertRecord)

	// hospital
	r.GET("/api/fetchHosList", handler.FetchHospitalList) // fetch all hospitals
	r.POST("/api/addHos", handler.AddHospital)            // add hospital
	r.POST("/api/modifyHos", handler.ModifyHospital)      // modify hospital
	r.DELETE("/api/deleteHos", handler.DeleteHospital)    // delete hospital

	// sms
	r.POST("/api/sendSMS", sms.Request)
	r.POST("/api/validateSMS", sms.Validate)

	// swagger
	r.GET("/swagger/*any", ginSwagger.WrapHandler(swaggerFiles.Handler))
	return r
}
